/* Copyright (c) 2009, Canonical Ltd. All rights reserved. */

YUI.add('lazr.anim', function(Y) {

Y.namespace('lazr.anim');

/**
 * @function flash_in
 * @description Create a flash-in animation object.  Dynamically checks
 * the 'to' property to see that the node's color isn't "transparent".
 * @param cfg Additional Y.Anim configuration.
 * @return Y.Anim instance
 */
Y.lazr.anim.flash_in = function(cfg) {
    var acfg = Y.merge(Y.lazr.anim.flash_in.defaults, cfg);
    var anim = new Y.Anim(acfg);

    // We need to validate the config afterwards because some of the
    // properties may be dynamic.
    var to = acfg.to;

    // Check the background color to make sure it isn't 'transparent'.
    if (to && typeof to.backgroundColor === 'function') {
        var bg = to.backgroundColor.call(anim, anim.get('node'));
        if (bg == 'transparent') {
            Y.fail("Can not animate to a 'transparent' background " +
                "in '" + anim + "'");
        }
    }

    // Reset the background color. This is normally only necessary when the
    // original background color of the node or its parent are not white,
    // since we normally fade to white.
    var original_bg = null;
    anim.on('start', function () {
        original_bg = anim.get('node').getStyle('backgroundColor');
    });
    anim.on('end', function () {
        anim.get('node').setStyle('backgroundColor', original_bg);
    });
    return anim;
};

Y.lazr.anim.flash_in.defaults = {
    duration: 1,
    easing: Y.Easing.easeIn,
    from: { backgroundColor: '#FFFF00' },
    to: { backgroundColor: '#FFFFFF' }
};



/**
 * @function green_flash
 * @description A green flash and fade, used to indicate new page data.
 * @param cfg Additional Y.Anim configuration.
 * @return Y.Anim instance
 */
Y.lazr.anim.green_flash = function(cfg) {
    return Y.lazr.anim.flash_in(
        Y.merge(Y.lazr.anim.green_flash.defaults, cfg));
};

Y.lazr.anim.green_flash.defaults = {
    from: { backgroundColor: '#90EE90' }
};


/**
 * @function red_flash
 * @description A red flash and fade, used to indicate errors.
 * @param cfg Additional Y.Anim configuration.
 * @return Y.Anim instance
 */
Y.lazr.anim.red_flash = function(cfg) {
    return Y.lazr.anim.flash_in(
        Y.merge(Y.lazr.anim.red_flash.defaults, cfg));
};

Y.lazr.anim.red_flash.defaults = {
    from: { backgroundColor: '#FF6666' }
};

}, "0.1", {"requires":["anim"]});
